Telemetry Consent:

Help us enhance our services by allowing anonymous usage collection. This data helps us understand which features are useful, and which can be retired - we are a small research project, and we can not afford to maintain features that are not useful. You have full control and can modify your choice at any time in the "Configuration" section.

If you can't help us with usage information, you can maybe help us with adopting and fixing some issues? We are an open-source project!
Want to know more? Learn about what we collect.
Feedback:

We value your feedback. Please help us understand why you declined telemetry:

Privacy concerns: I don't want my usage data to be collected.
Performance concerns: I'm worried it might slow down the application.
Trust issues: I'm not sure how the data will be used.
Other:
Characters: {{ customReason.length || 0 }} / 2000